@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Mock data creation
 
-our $VERSION = '0.1200';
+our $VERSION = '0.1201';
 
 use strict;
 use warnings;
@@ -385,7 +385,7 @@ Mock::Populate - Mock data creation
 
 =head1 VERSION
 
-version 0.1200
+version 0.1201
 
 =head1 SYNOPSIS
 
@@ -541,8 +541,7 @@ This function uses single letter identifiers:
 
   $results = shuffler(@items)
 
-Return a shuffled list of B<items>.  The items and number of data-points are
-optional.  The defaults are:
+Return a shuffled list of B<items>.  The items are optional.  The defaults are:
 
   items: a b c d e f g h i j
 
@@ -561,9 +560,6 @@ data-points are optional.  The defaults are:
   length: 8
   N:      10
 
-* This function is nearly identical to the L<Data::SimplePassword>
-C<rndpassword> program, but allows you to generate a finite number of results.
-
 =head3 Types
 
   Types     Output sample     Character set
